# Package-dkconverter

- This package helps you to convert decimal numbers to other numeral system representations.
- File named **"conv.py"** has all the functions that do so.

## Getting started

### Install Package using pip
> pip install dkconverters==1.0.0

### Import package in your pyfile
```python
from dkconverter import conv
```
### Get More Info on Functions Used

For your reference info on functions used are added to readme and an Example Code is also added for reference.
```python
from dkconverter import conv
help(conv)
print(conv.bina(10))
print(conv.octl(10))
print(conv.hexdcml(10))
```

## Function-*bina*

It converts decimal number into binary number which is passed as an argument to this function.
===

## Function-*octl*

It converts decimal number into octal number which is passed as an argument to this function.
===

## Function-*hexdcml*

It converts decimal number into hexadecimal number which is passed as an argument to this function.
===